############
warn-scraper
############

Command-line interface for downloading WARN Act notices of qualified plant closings and mass layoffs from state government websites


Installation
############

Use `pip` or `pipenv` to install the Python library and command-line interface.

.. code-block:: bash

    pipenv install warn-scraper


Documentation
#############

.. toctree::
   :glob:
   :maxdepth: 1

   usage
   contributing
   releasing
   sources
   reference


Links
#####

* Documentation: `warn-scraper.readthedocs.io <https://warn-scraper.readthedocs.io/>`_
* Repository: `github.com/biglocalnews/warn-scraper <https://github.com/biglocalnews/warn-scraper>`_
* Packaging: `pypi.org/project/warn-scraper <https://pypi.org/project/warn-scraper/>`_

About
#####

The project is sponsored by `Big Local News <https://biglocalnews.org/#/about>`_, a program at Stanford University that collects data for impactful journalism. The code is maintained by Stanford Lecturer `Serdar Tumgoren <https://comm.stanford.edu/faculty-tumgoren/>`_ and `Ben Welsh <https://palewi.re/who-is-ben-welsh/>`_, a visiting data journalist from the Los Angeles Times.
